.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/ezeeresult.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/ezeeresult
    .. image:: https://readthedocs.org/projects/ezeeresult/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://ezeeresult.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/ezeeresult/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/ezeeresult
    .. image:: https://img.shields.io/pypi/v/ezeeresult.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/ezeeresult/
    .. image:: https://img.shields.io/conda/vn/conda-forge/ezeeresult.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/ezeeresult
    .. image:: https://pepy.tech/badge/ezeeresult/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/ezeeresult
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/ezeeresult

.. .. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
..     :alt: Project generated with PyScaffold
..     :target: https://pyscaffold.org/

.. |

==========
ezeeresult
==========


    Marks scraper for MCA (REVISED 2020) latest semester.


.. A longer description of your project goes here...


.. _pyscaffold-notes:

.. Note
.. ====

.. This project has been set up using PyScaffold 4.3.1. For details and usage
.. information on PyScaffold see https://pyscaffold.org/.
